Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConfigMapSet ¶
type ConfigMapSet interface {
// Get the set stored keys
Keys() sets.String
// List of resources stored in the set. Pass an optional filter function to filter on the list.
List(filterResource ...func(*v1.ConfigMap) bool) []*v1.ConfigMap
// Unsorted list of resources stored in the set. Pass an optional filter function to filter on the list.
UnsortedList(filterResource ...func(*v1.ConfigMap) bool) []*v1.ConfigMap
// Return the Set as a map of key to resource.
Map() map[string]*v1.ConfigMap
// Insert a resource into the set.
Insert(configMap ...*v1.ConfigMap)
// Compare the equality of the keys in two sets (not the resources themselves)
Equal(configMapSet ConfigMapSet) bool
// Check if the set contains a key matching the resource (not the resource itself)
Has(configMap ezkube.ResourceId) bool
// Delete the key matching the resource
Delete(configMap ezkube.ResourceId)
// Return the union with the provided set
Union(set ConfigMapSet) ConfigMapSet
// Return the difference with the provided set
Difference(set ConfigMapSet) ConfigMapSet
// Return the intersection with the provided set
Intersection(set ConfigMapSet) ConfigMapSet
// Find the resource with the given ID
Find(id ezkube.ResourceId) (*v1.ConfigMap, error)
// Get the length of the set
Length() int
// returns the generic implementation of the set
Generic() sksets.ResourceSet
// returns the delta between this and and another ConfigMapSet
Delta(newSet ConfigMapSet) sksets.ResourceDelta
// Create a deep copy of the current ConfigMapSet
Clone() ConfigMapSet
}
func NewConfigMapSet ¶
func NewConfigMapSet(configMapList ...*v1.ConfigMap) ConfigMapSet
func NewConfigMapSetFromList ¶
func NewConfigMapSetFromList(configMapList *v1.ConfigMapList) ConfigMapSet
type EndpointsSet ¶ added in v0.1.2
type EndpointsSet interface {
// Get the set stored keys
Keys() sets.String
// List of resources stored in the set. Pass an optional filter function to filter on the list.
List(filterResource ...func(*v1.Endpoints) bool) []*v1.Endpoints
// Unsorted list of resources stored in the set. Pass an optional filter function to filter on the list.
UnsortedList(filterResource ...func(*v1.Endpoints) bool) []*v1.Endpoints
// Return the Set as a map of key to resource.
Map() map[string]*v1.Endpoints
// Insert a resource into the set.
Insert(endpoints ...*v1.Endpoints)
// Compare the equality of the keys in two sets (not the resources themselves)
Equal(endpointsSet EndpointsSet) bool
// Check if the set contains a key matching the resource (not the resource itself)
Has(endpoints ezkube.ResourceId) bool
// Delete the key matching the resource
Delete(endpoints ezkube.ResourceId)
// Return the union with the provided set
Union(set EndpointsSet) EndpointsSet
// Return the difference with the provided set
Difference(set EndpointsSet) EndpointsSet
// Return the intersection with the provided set
Intersection(set EndpointsSet) EndpointsSet
// Find the resource with the given ID
Find(id ezkube.ResourceId) (*v1.Endpoints, error)
// Get the length of the set
Length() int
// returns the generic implementation of the set
Generic() sksets.ResourceSet
// returns the delta between this and and another EndpointsSet
Delta(newSet EndpointsSet) sksets.ResourceDelta
// Create a deep copy of the current EndpointsSet
Clone() EndpointsSet
}
func NewEndpointsSet ¶ added in v0.1.2
func NewEndpointsSet(endpointsList ...*v1.Endpoints) EndpointsSet
func NewEndpointsSetFromList ¶ added in v0.1.2
func NewEndpointsSetFromList(endpointsList *v1.EndpointsList) EndpointsSet
type NamespaceSet ¶
type NamespaceSet interface {
// Get the set stored keys
Keys() sets.String
// List of resources stored in the set. Pass an optional filter function to filter on the list.
List(filterResource ...func(*v1.Namespace) bool) []*v1.Namespace
// Unsorted list of resources stored in the set. Pass an optional filter function to filter on the list.
UnsortedList(filterResource ...func(*v1.Namespace) bool) []*v1.Namespace
// Return the Set as a map of key to resource.
Map() map[string]*v1.Namespace
// Insert a resource into the set.
Insert(namespace ...*v1.Namespace)
// Compare the equality of the keys in two sets (not the resources themselves)
Equal(namespaceSet NamespaceSet) bool
// Check if the set contains a key matching the resource (not the resource itself)
Has(namespace ezkube.ResourceId) bool
// Delete the key matching the resource
Delete(namespace ezkube.ResourceId)
// Return the union with the provided set
Union(set NamespaceSet) NamespaceSet
// Return the difference with the provided set
Difference(set NamespaceSet) NamespaceSet
// Return the intersection with the provided set
Intersection(set NamespaceSet) NamespaceSet
// Find the resource with the given ID
Find(id ezkube.ResourceId) (*v1.Namespace, error)
// Get the length of the set
Length() int
// returns the generic implementation of the set
Generic() sksets.ResourceSet
// returns the delta between this and and another NamespaceSet
Delta(newSet NamespaceSet) sksets.ResourceDelta
// Create a deep copy of the current NamespaceSet
Clone() NamespaceSet
}
func NewNamespaceSet ¶
func NewNamespaceSet(namespaceList ...*v1.Namespace) NamespaceSet
func NewNamespaceSetFromList ¶
func NewNamespaceSetFromList(namespaceList *v1.NamespaceList) NamespaceSet
type NodeSet ¶
type NodeSet interface {
// Get the set stored keys
Keys() sets.String
// List of resources stored in the set. Pass an optional filter function to filter on the list.
List(filterResource ...func(*v1.Node) bool) []*v1.Node
// Unsorted list of resources stored in the set. Pass an optional filter function to filter on the list.
UnsortedList(filterResource ...func(*v1.Node) bool) []*v1.Node
// Return the Set as a map of key to resource.
Map() map[string]*v1.Node
// Insert a resource into the set.
Insert(node ...*v1.Node)
// Compare the equality of the keys in two sets (not the resources themselves)
Equal(nodeSet NodeSet) bool
// Check if the set contains a key matching the resource (not the resource itself)
Has(node ezkube.ResourceId) bool
// Delete the key matching the resource
Delete(node ezkube.ResourceId)
// Return the union with the provided set
Union(set NodeSet) NodeSet
// Return the difference with the provided set
Difference(set NodeSet) NodeSet
// Return the intersection with the provided set
Intersection(set NodeSet) NodeSet
// Find the resource with the given ID
Find(id ezkube.ResourceId) (*v1.Node, error)
// Get the length of the set
Length() int
// returns the generic implementation of the set
Generic() sksets.ResourceSet
// returns the delta between this and and another NodeSet
Delta(newSet NodeSet) sksets.ResourceDelta
// Create a deep copy of the current NodeSet
Clone() NodeSet
}
func NewNodeSet ¶
func NewNodeSetFromList ¶
type PodSet ¶
type PodSet interface {
// Get the set stored keys
Keys() sets.String
// List of resources stored in the set. Pass an optional filter function to filter on the list.
List(filterResource ...func(*v1.Pod) bool) []*v1.Pod
// Unsorted list of resources stored in the set. Pass an optional filter function to filter on the list.
UnsortedList(filterResource ...func(*v1.Pod) bool) []*v1.Pod
// Return the Set as a map of key to resource.
Map() map[string]*v1.Pod
// Insert a resource into the set.
Insert(pod ...*v1.Pod)
// Compare the equality of the keys in two sets (not the resources themselves)
Equal(podSet PodSet) bool
// Check if the set contains a key matching the resource (not the resource itself)
Has(pod ezkube.ResourceId) bool
// Delete the key matching the resource
Delete(pod ezkube.ResourceId)
// Return the union with the provided set
Union(set PodSet) PodSet
// Return the difference with the provided set
Difference(set PodSet) PodSet
// Return the intersection with the provided set
Intersection(set PodSet) PodSet
// Find the resource with the given ID
Find(id ezkube.ResourceId) (*v1.Pod, error)
// Get the length of the set
Length() int
// returns the generic implementation of the set
Generic() sksets.ResourceSet
// returns the delta between this and and another PodSet
Delta(newSet PodSet) sksets.ResourceDelta
// Create a deep copy of the current PodSet
Clone() PodSet
}
func NewPodSetFromList ¶
type SecretSet ¶
type SecretSet interface {
// Get the set stored keys
Keys() sets.String
// List of resources stored in the set. Pass an optional filter function to filter on the list.
List(filterResource ...func(*v1.Secret) bool) []*v1.Secret
// Unsorted list of resources stored in the set. Pass an optional filter function to filter on the list.
UnsortedList(filterResource ...func(*v1.Secret) bool) []*v1.Secret
// Return the Set as a map of key to resource.
Map() map[string]*v1.Secret
// Insert a resource into the set.
Insert(secret ...*v1.Secret)
// Compare the equality of the keys in two sets (not the resources themselves)
Equal(secretSet SecretSet) bool
// Check if the set contains a key matching the resource (not the resource itself)
Has(secret ezkube.ResourceId) bool
// Delete the key matching the resource
Delete(secret ezkube.ResourceId)
// Return the union with the provided set
Union(set SecretSet) SecretSet
// Return the difference with the provided set
Difference(set SecretSet) SecretSet
// Return the intersection with the provided set
Intersection(set SecretSet) SecretSet
// Find the resource with the given ID
Find(id ezkube.ResourceId) (*v1.Secret, error)
// Get the length of the set
Length() int
// returns the generic implementation of the set
Generic() sksets.ResourceSet
// returns the delta between this and and another SecretSet
Delta(newSet SecretSet) sksets.ResourceDelta
// Create a deep copy of the current SecretSet
Clone() SecretSet
}
func NewSecretSet ¶
func NewSecretSetFromList ¶
func NewSecretSetFromList(secretList *v1.SecretList) SecretSet
type ServiceAccountSet ¶
type ServiceAccountSet interface {
// Get the set stored keys
Keys() sets.String
// List of resources stored in the set. Pass an optional filter function to filter on the list.
List(filterResource ...func(*v1.ServiceAccount) bool) []*v1.ServiceAccount
// Unsorted list of resources stored in the set. Pass an optional filter function to filter on the list.
UnsortedList(filterResource ...func(*v1.ServiceAccount) bool) []*v1.ServiceAccount
// Return the Set as a map of key to resource.
Map() map[string]*v1.ServiceAccount
// Insert a resource into the set.
Insert(serviceAccount ...*v1.ServiceAccount)
// Compare the equality of the keys in two sets (not the resources themselves)
Equal(serviceAccountSet ServiceAccountSet) bool
// Check if the set contains a key matching the resource (not the resource itself)
Has(serviceAccount ezkube.ResourceId) bool
// Delete the key matching the resource
Delete(serviceAccount ezkube.ResourceId)
// Return the union with the provided set
Union(set ServiceAccountSet) ServiceAccountSet
// Return the difference with the provided set
Difference(set ServiceAccountSet) ServiceAccountSet
// Return the intersection with the provided set
Intersection(set ServiceAccountSet) ServiceAccountSet
// Find the resource with the given ID
Find(id ezkube.ResourceId) (*v1.ServiceAccount, error)
// Get the length of the set
Length() int
// returns the generic implementation of the set
Generic() sksets.ResourceSet
// returns the delta between this and and another ServiceAccountSet
Delta(newSet ServiceAccountSet) sksets.ResourceDelta
// Create a deep copy of the current ServiceAccountSet
Clone() ServiceAccountSet
}
func NewServiceAccountSet ¶
func NewServiceAccountSet(serviceAccountList ...*v1.ServiceAccount) ServiceAccountSet
func NewServiceAccountSetFromList ¶
func NewServiceAccountSetFromList(serviceAccountList *v1.ServiceAccountList) ServiceAccountSet
type ServiceSet ¶
type ServiceSet interface {
// Get the set stored keys
Keys() sets.String
// List of resources stored in the set. Pass an optional filter function to filter on the list.
List(filterResource ...func(*v1.Service) bool) []*v1.Service
// Unsorted list of resources stored in the set. Pass an optional filter function to filter on the list.
UnsortedList(filterResource ...func(*v1.Service) bool) []*v1.Service
// Return the Set as a map of key to resource.
Map() map[string]*v1.Service
// Insert a resource into the set.
Insert(service ...*v1.Service)
// Compare the equality of the keys in two sets (not the resources themselves)
Equal(serviceSet ServiceSet) bool
// Check if the set contains a key matching the resource (not the resource itself)
Has(service ezkube.ResourceId) bool
// Delete the key matching the resource
Delete(service ezkube.ResourceId)
// Return the union with the provided set
Union(set ServiceSet) ServiceSet
// Return the difference with the provided set
Difference(set ServiceSet) ServiceSet
// Return the intersection with the provided set
Intersection(set ServiceSet) ServiceSet
// Find the resource with the given ID
Find(id ezkube.ResourceId) (*v1.Service, error)
// Get the length of the set
Length() int
// returns the generic implementation of the set
Generic() sksets.ResourceSet
// returns the delta between this and and another ServiceSet
Delta(newSet ServiceSet) sksets.ResourceDelta
// Create a deep copy of the current ServiceSet
Clone() ServiceSet
}
func NewServiceSet ¶
func NewServiceSet(serviceList ...*v1.Service) ServiceSet
func NewServiceSetFromList ¶
func NewServiceSetFromList(serviceList *v1.ServiceList) ServiceSet
Click to show internal directories.
Click to hide internal directories.